@@ -227,7 +227,10 @@ int c_set_window_geometry(lua_State *lua)
 	int type3=lua_type(lua,3);
 	int type4=lua_type(lua,4);
 
-	if ((type1!=LUA_TNUMBER) || (type2!=LUA_TNUMBER) || (type3!=LUA_TNUMBER) || (type4!=LUA_TNUMBER)) {
+	if ((type1!=LUA_TNUMBER) ||
+	    (type2!=LUA_TNUMBER) ||
+	    (type3!=LUA_TNUMBER) ||
+	    (type4!=LUA_TNUMBER)) {
 		luaL_error(lua,"set_window_geometry: %s", four_indata_expected_error);
 		return 0;
 	}
@@ -273,7 +276,10 @@ int c_set_window_geometry2(lua_State *lua)
 	int type3=lua_type(lua,3);
 	int type4=lua_type(lua,4);
 
-	if ((type1!=LUA_TNUMBER) || (type2!=LUA_TNUMBER) || (type3!=LUA_TNUMBER) || (type4!=LUA_TNUMBER)) {
+	if ((type1!=LUA_TNUMBER) ||
+	    (type2!=LUA_TNUMBER) ||
+	    (type3!=LUA_TNUMBER) ||
+	    (type4!=LUA_TNUMBER)) {
 		luaL_error(lua,"set_window_geometry: %s", four_indata_expected_error);
 		return 0;
 	}
@@ -720,8 +726,6 @@ int c_decorate_window(lua_State *lua)
 int c_set_window_workspace(lua_State *lua)
 {
 	int top=lua_gettop(lua);
-	WnckScreen *screen;
-	WnckWorkspace *workspace;
 
 	if (top!=1) {
 		luaL_error(lua,"set_window_workspace: %s",one_indata_expected_error);
@@ -740,6 +744,8 @@ int c_set_window_workspace(lua_State *lua)
 	WnckWindow *window=get_current_window();
 
 	if (window) {
+		WnckScreen *screen;
+		WnckWorkspace *workspace;
 
 		screen=wnck_window_get_screen(window);
 		workspace=wnck_screen_get_workspace(screen,number-1);
@@ -764,8 +770,6 @@ int c_set_window_workspace(lua_State *lua)
 int c_change_workspace(lua_State *lua)
 {
 	int top=lua_gettop(lua);
-	WnckScreen *screen;
-	WnckWorkspace *workspace;
 	GTimeVal timestamp;
 
 	if (top!=1) {
@@ -784,6 +788,9 @@ int c_change_workspace(lua_State *lua)
 
 	WnckWindow *window=get_current_window();
 	if (window) {
+		WnckScreen *screen;
+		WnckWorkspace *workspace;
+
 		screen=wnck_window_get_screen(window);
 		workspace=wnck_screen_get_workspace(screen,number-1);
 
