@@ -2,18 +2,18 @@
  *	This file is part of devilspie2
  *	Copyright (C) 2001 Havoc Pennington, 2011-2012 Andreas Rönnquist
  *
- *	devilspie2 is free software: you can redistribute it and/or 
- *	modify it under the terms of the GNU General Public License as published 
+ *	devilspie2 is free software: you can redistribute it and/or
+ *	modify it under the terms of the GNU General Public License as published
  *	by the Free Software Foundation, either version 3 of the License, or
  *	(at your option) any later version.
- * 
+ *
  *	devilspie2 is distributed in the hope that it will be useful,
  *	but WITHOUT ANY WARRANTY; without even the implied warranty of
  *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  *	GNU General Public License for more details.
- * 
+ *
  *	You should have received a copy of the GNU General Public License
- *	along with devilspie2.  
+ *	along with devilspie2.
  *	If not, see <http://www.gnu.org/licenses/>.
  */
 
@@ -37,4 +37,6 @@ int my_wnck_error_trap_pop();
 gboolean decorate_window(WnckWindow *window);
 gboolean undecorate_window(WnckWindow *window);
 
+char* my_wnck_get_string_property_latin1 (Window xwindow, Atom atom);
+
 #endif /*__HEADER_XUTILS_*/
